@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 our $SOURCE = 'CPAN';
 ## $SOURCE = 'GitHub';  # COMMENT
 # the line above will be commented out by Dist::Zilla
@@ -372,9 +372,10 @@ sub data_upload {
 
     # code cribbed from JIRA::REST
     #
+    my $url      = $self->rest_api_url_base . $args->{url};
     my $rest     = $self->REST_CLIENT;
     my $response = $rest->getUseragent()->post(
-        $self->rest_api_url_base . $args->{url},
+        $url,
         %{ $rest->{_headers} },
         'X-Atlassian-Token' => 'nocheck',
         'Content-Type'      => 'form-data',
@@ -423,6 +424,7 @@ sub data_upload {
 #pod }
 #pod catch {
 #pod     $results = $_;
+#pod     diag($test->REST_CLIENT->getHost);
 #pod };
 #pod
 #pod my $test1_ok = isa_ok( $results, 'HTTP::Response', $test1_name );
@@ -682,7 +684,7 @@ sub rest_api_url_base {
     else {
         my ( $base )
             = $self->REST_CLIENT->getHost =~ m{^(.+?rest/api/[^/]+)/?}xms;
-        return $base;
+        return $base // $self->REST_CLIENT->getHost . '/rest/api/latest';
     }
 }
 
@@ -845,7 +847,7 @@ JIRA::REST::Class - An OO Class module built atop L<JIRA::REST|JIRA::REST> for d
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -1401,6 +1403,7 @@ try {
 }
 catch {
     $results = $_;
+    diag($test->REST_CLIENT->getHost);
 };
 
 my $test1_ok = isa_ok( $results, 'HTTP::Response', $test1_name );
